#!/usr/bin/env node

var fs = require("fs"),
    markdown = require("markdown").markdown,
    highlight = require("highlight").Highlight,
    argv = require('optimist').
        usage('Usage: $0 -s [directory]  -o [directory]').
        demand(['s','o']).
        argv,
    sourceDir = argv.s,
    outputDir = argv.o,
    pathlib = require("path"),
    listing = [];

walkDirectory();

listing.forEach(function(item){
    handleFile(item);
});



function walkDirectory(directory, level){
    level = level || 0;
    directory = directory || "";
    if(level>10){
        return;
    }
    var list = fs.readdirSync(pathlib.join(sourceDir, directory));
    list.forEach(function(element){
        var fullName = pathlib.join(sourceDir, directory, element),
            relativeName = pathlib.join(directory, element),
            stat = fs.statSync(fullName);

        if(stat.isDirectory(fullName)){
            walkDirectory(relativeName, level + 1);
        }else if(stat.isFile(fullName)){
            if(element.match(/\.md$/i)){
                listing.push(relativeName);
            }
        }
    });
}


function handleFile(item){
    var contents = fs.readFileSync(pathlib.join(sourceDir, item), "utf-8");

    contents = markdown.toHTML(contents);
    contents = highlight(contents, false, true);

    checkDir(item);

    item = item.replace(/\.md$/i,".html");

    try{
        fs.writeFileSync(pathlib.join(outputDir, item), contents);
    }catch(E){
        console.log("FAILED WRITING FILE " + item);
        console.log(E);
        process.exit;
    }

    console.log(item+" OK");

}

function checkDir(filepath){
    var path = pathlib.join(outputDir, filepath).split("/"),
        cur = [],
        dir, stats;

    path.pop();

    for(var i=0, len = path.length; i<len; i++){
        cur.push(path.shift());
        dir = cur.join("/");
        try{
            stats = fs.statSync(dir);
        }catch(E){
            createDir(dir);
        }
    }
}

function createDir(dir){
    try{
        fs.mkdirSync(dir, parseInt(666, 8));
    }catch(E){
        console.log("FAILED CREATING DIR "+dir);
        console.log(E);
        process.exit;
    }

}